unit mainfrm;

interface

uses
  SysUtils, Types, Classes, QGraphics, QControls, QForms, QDialogs,
  QStdCtrls, QExtCtrls, QButtons, XReport, Qt, QDBCtrls, QGrids, QDBGrids
{$IFDEF LINUX}
  ,LibC
{$ELSE}
  ,ShellApi, WinTypes
{$ENDIF}
  ;

const descriptions:array[0..10] of string =
 ('Simple report from COUNTRY table',
  'Clone of "Customers" report from M.A.S.T. demo application',
  'Clone of "Orders" report from M.A.S.T. demo application',
  'Clone of "Invoice" report from M.A.S.T. demo application',
  'Report with pictures and memos',
  'Basic Master/Detail report with sub-list',
  'This is an example of a Master/Detail report that uses some extra code to customize the output.',
  'Report with memos and borders',
  'Report with two columns',
  'Demonstration report that show how to link several reports together as a single report.',
  'This report uses  two queries to demonstrate how to handle subtotals and group breaks. Most grouping and totaling tasks can be accomplished without coding.  This report does not have any code, everything is set by the component properties.');

type
  TfrmMain = class(TForm)
    Panel1: TPanel;
    Panel2: TPanel;
    RGRpt: TRadioGroup;
    Memo1: TMemo;
    Panel3: TPanel;
    Image2: TImage;
    Label1: TLabel;
    VersionLbl: TLabel;
    Label3: TLabel;
    BitBtn1: TBitBtn;
    BitBtn2: TBitBtn;
    BitBtn3: TBitBtn;
    BitBtn4: TBitBtn;
    BitBtn5: TBitBtn;
    Label2: TLabel;
    CBExTp: TComboBox;
    SD: TSaveDialog;
    Label4: TLabel;
    procedure RGRptClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure BitBtn5Click(Sender: TObject);
    procedure BitBtn1Click(Sender: TObject);
    procedure BitBtn2Click(Sender: TObject);
    procedure BitBtn3Click(Sender: TObject);
    procedure BitBtn4Click(Sender: TObject);
    procedure Label4Click(Sender: TObject);
    procedure Label4MouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure Panel3MouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure CBExTpChange(Sender: TObject);
  private
    { Private declarations }
    Curr_Report:TXReport;
    function GetParams:boolean;
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

uses rptmod, pickinvc;

{$R *.xfm}

procedure TfrmMain.FormCreate(Sender: TObject);
begin
ReportModule:=TReportModule.Create(Self);
RGRptClick(Sender);
end;

procedure TfrmMain.CBExTpChange(Sender: TObject);
begin
if CBExTp.ItemIndex=0 then
  begin
  SD.DefaultExt:='csv';
  SD.Filter:='*.csv|*.txt';
  end
else
  begin
  SD.DefaultExt:='html';
  SD.Filter:='*.html|*.htm';
  end;
end;

procedure TfrmMain.RGRptClick(Sender: TObject);
begin
Memo1.Lines.Text:=descriptions[RGRpt.ItemIndex];
with ReportModule do
  case RGRpt.ItemIndex of
    0: Curr_Report:=SimpleRpt;
    1: begin
       QCustomers.IndexFieldNames:='LastInvoiceDate';
       Curr_Report:=CustReport;
       end;
    2: begin
       QOrders.MasterSource:=nil;
       QOrders.MasterFields:='';
       QOrders.IndexFieldNames:='SaleDate';
       Curr_Report:=OrdReport;
       end;
    3: begin
       QOrders.MasterSource:=nil;
       QOrders.MasterFields:='';
       QOrders.IndexFieldNames:='OrderNo';
       Curr_Report:=InvReport;
       end;
    4: Curr_Report:=BioReport;
    5: begin
       QOrders.MasterSource:=DCustomers;
       QOrders.MasterFields:='CustNo';
       QOrders.IndexFieldNames:='CustNo;Terms';
       Curr_Report:=BasicMD;
       end;
    6: begin
       QOrders.MasterSource:=DCustomers;
       QOrders.MasterFields:='CustNo';
       QOrders.IndexFieldNames:='CustNo;Terms';
       Curr_Report:=AdvMD;
       end;
    7: Curr_Report:=BordeRpt;
    8: Curr_Report:=MultiCol;
    9: Curr_Report:=CompRep;
  else
    raise Exception.Create('Not implemented.');
  end;

end;

function TfrmMain.GetParams:boolean;
begin
result:=True;
if RGRpt.ItemIndex=3 then
  begin
  ReportModule.QOrders.First;
  PickOrderNoDlg.ShowModal;
  if PickOrderNoDlg.ModalResult=mrOk then
    begin
    result:=True;
    end;
  end;
end;

procedure TfrmMain.BitBtn5Click(Sender: TObject);
begin
Application.Terminate;
end;

procedure TfrmMain.BitBtn1Click(Sender: TObject);
begin
if GetParams then Curr_Report.Print;
end;

procedure TfrmMain.BitBtn2Click(Sender: TObject);
begin
if GetParams then
  Curr_Report.Preview;
end;

procedure TfrmMain.BitBtn3Click(Sender: TObject);
begin
Curr_Report.Design;
end;

procedure TfrmMain.BitBtn4Click(Sender: TObject);
var str:TFileStream;
     tp:TXRptExportType;
begin
if not GetParams then exit;
if SD.Execute then
  begin
  str:=TFileStream.Create(SD.FileName,fmCreate);
  if CBExTp.ItemIndex=0 then tp:=xxCSV else tp:=xxHTML;
  Curr_Report.ExportToStream(str,tp);
  str.Free;
  end;
end;

// Web page handling

procedure TfrmMain.Label4Click(Sender: TObject);
begin
{$IFNDEF WIN32}
LibC.system('kfmclient openProfile webbrowsing http://www.x-szoft.hu &');
{$ELSE}
ShellExecute(QWidget_WinID(frmMain.Handle),'open','http://www.x-szoft.hu',nil,nil,SW_SHOW);
{$ENDIF}
end;

procedure TfrmMain.Label4MouseMove(Sender: TObject; Shift: TShiftState; X,
  Y: Integer);
begin
Label4.Font.Style:=[fsUnderline];
end;

procedure TfrmMain.Panel3MouseMove(Sender: TObject; Shift: TShiftState; X,
  Y: Integer);
begin
Label4.Font.Style:=[];
end;

end.
