unit XRptBarcode;

interface

uses XReport, PrtComps, Classes, SysUtils, QGraphics, Barcode, QPrinters, DB;

type
  TXRBOrientation = (TXRBHorizontal, TXRBVertical);
  TXRBarcode = class(TXRDBPrintable)
  private
    FBarcode:TASBarcode;
    FOrientation:TXRBOrientation;
    procedure SetBarcode(const Value: TASBarcode);
    function GetBarcode: TASBarcode;
    function GetCheckSum: boolean;
    function GetCheckSumMethod: TCheckSumMethod;
    function GetColor: TColor;
    function GetColorBar: TColor;
    function GetText: string;
    function GetTyp: TBarcodeType;
    procedure SetOrientation(const AOrientation:TXRBOrientation);
    procedure SetCheckSum(const Value: boolean);
    procedure SetCheckSumMethod(const Value: TCheckSumMethod);
    procedure SetColor(const Value: TColor);
    procedure SetColorBar(const Value: TColor);
    procedure SetText(const Value: string);
    procedure SetTyp(const Value: TBarcodeType);
  public
    constructor Create(AReport:TXReport; AOwner:TXRPtObj); override;
    destructor Destroy; override;
    procedure Draw(c:TXPrtCanvas;desing:boolean); override;
    property Barcode :TASBarcode read GetBarcode write SetBarcode;
  published
    property Checksum :boolean read GetCheckSum write SetCheckSum default FALSE;
    property CheckSumMethod :TCheckSumMethod read GetCheckSumMethod write SetCheckSumMethod default csmModulo10;
    property Color :TColor read GetColor write SetColor default clWhite;
    property ColorBar :TColor read GetColorBar write SetColorBar default clBlack;
    property Text :string read GetText write SetText;
    property Typ :TBarcodeType read GetTyp write SetTyp default bcCode_2_5_interleaved;
    property Orientation:TXRBOrientation read FOrientation write SetOrientation default TXRBHorizontal;
    end;

implementation

{$R XRExt.res}

constructor TXRBarcode.Create(AReport:TXReport; AOwner:TXRPtObj);
begin
inherited;
FBarcode:=TASBarcode.Create(nil);
FBarcode.Height:=50;
FOrientation:=TXRBHorizontal;
end;

destructor TXRBarcode.Destroy;
begin
FreeAndNil(FBarcode);
inherited;
end;

procedure TXRBarcode.Draw(c:TXPrtCanvas;desing:boolean);
var bmp:TBitmap;
begin
try

  bmp:=TBitmap.Create;
  if FOrientation=TXRBHorizontal then
    begin
    FBarcode.Width:=Round(FWidth*4);
    FBarcode.Height:=Round(5);
    Barcode.Angle:=0;
    end
  else
    begin
    FBarcode.Height:=Round(FWidth*4);
    FBarcode.Width:=Round(5);
    Barcode.Angle:=90;
    end;

  if FDataLink.Field<>nil then
    Barcode.Text:=FDataLink.Field.AsString;

  bmp.Width:=FBarcode.CanvasWidth;
  bmp.Height:=FBarcode.CanvasHeight;

  Barcode.DrawBarcode(bmp.Canvas);

  c.Bitmap(0,0, FWidth, FHeight,bmp);

//  c.Image(0,0,bmp);

  bmp.Free;

except
  on E:Exception do begin Barcode.Text:=''; raise Exception.Create(E.Message); end;
  end;

end;

function TXRBarcode.GetBarcode: TASBarcode;
begin
Result:=FBarcode;
end;

function TXRBarcode.GetCheckSum: boolean;
begin
Result:=Barcode.CheckSum;
end;

function TXRBarcode.GetCheckSumMethod: TCheckSumMethod;
begin
Result:=Barcode.CheckSumMethod;
end;

function TXRBarcode.GetColor: TColor;
begin
Result:=Barcode.Color;
end;

function TXRBarcode.GetColorBar: TColor;
begin
Result:=Barcode.ColorBar;
end;

function TXRBarcode.GetText:string;
begin
Result:=Barcode.Text;
end;

function TXRBarcode.GetTyp:TBarcodeType;
begin
Result:=Barcode.Typ;
end;

procedure TXRBarcode.SetOrientation(const AOrientation:TXRBOrientation);
begin
FOrientation:=AOrientation;
Invalidate;
end;

procedure TXRBarcode.SetBarcode(const Value: TASBarcode);
begin
FBarcode.Assign(Value);
end;

procedure TXRBarcode.SetCheckSum(const Value: boolean);
begin
Barcode.CheckSum:=Value;
Invalidate;
end;

procedure TXRBarcode.SetCheckSumMethod(const Value: TCheckSumMethod);
begin
Barcode.CheckSumMethod := Value;
Invalidate;
end;

procedure TXRBarcode.SetColor(const Value: TColor);
begin
Barcode.Color := Value;
Invalidate;
end;

procedure TXRBarcode.SetColorBar(const Value: TColor);
begin
Barcode.ColorBar := Value;
Invalidate;
end;

procedure TXRBarcode.SetText(const Value: string);
begin
Barcode.Text := Value;
Invalidate;
end;

procedure TXRBarcode.SetTyp(const Value: TBarcodeType);
begin
Barcode.Typ := Value;
Invalidate;
end;

initialization
RegisterXRptObj('Extension',TXRBarcode,HInstance);

end.
